﻿'----------------------------------------------------------
'
' KX用サンプルコード
'
' 開発環境
'     Microsoft Visual Studio 2010
'     Version 10.0.30319.1 RTMRel
'     Microsoft .NET Framework
'     Version 4.5.51209 RTMRel
'
' Copyright (c) 2015 TAKASAGO.LTD.All Right Reserved.
'
' 2015/06/18 Created. [H.O.]
'
'----------------------------------------------------------
Public Class Form1
    Dim intOutPut As Integer    '出力状態 (0=OFF,1=ON)
    Dim dblVolt As Double       '設定電圧
    Dim dblCurr As Double       '設定電流
    Dim dblOvp As Double        '過電圧保護
    Dim dblOcp As Double        '過電流保護
    Dim dblMeasVolt As Double   '計測電圧
    Dim dblMeasCurr As Double   '計測電流
    Dim srtRcvData As String    '受信文字列

    '------------------------------------------------------
    'フォームロード
    '------------------------------------------------------
    Private Sub Form1_Load(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles MyBase.Load

        '通信設定
        With SerialPort1
            .PortName = "COM1"                      'ポート番号指定
            .BaudRate = 9600                        'ボーレート指定
            .DataBits = 8                           'データビット指定
            .Parity = IO.Ports.Parity.None          'パリティ指定
            .StopBits = IO.Ports.StopBits.One       'ストップビット指定
            .Handshake = IO.Ports.Handshake.None    'フロー制御指定
            .RtsEnable = True                       'RTS信号の有効化指定
        End With

        Try
            'ポートオープン
            SerialPort1.Open()
        Catch ex As Exception
        End Try

        If SerialPort1.IsOpen = True Then
            Data_Send("A1")                         'デバイスアドレス指定コマンド送信
            Data_Send("AR1")                        'アラームクリアコマンド送信
            Data_Send("TK4")                        'アラーム情報取得コマンド送信
            srtRcvData = Data_Receive()             'データ受信
            '受信文字列判定
            If srtRcvData.Contains("STAT") Then
                Me.Text = "サンプルコード(オンライン)"
            Else
                '通信異常発生
                Me.Text = "サンプルコード(オフライン)"
                Exit Sub
            End If
        Else
            'ポートオープン失敗
            Me.Text = "サンプルコード(オフライン)"
        End If

    End Sub

    '------------------------------------------------------
    'フォームクローズ
    '------------------------------------------------------
    Private Sub Form1_FormClosed(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles MyBase.FormClosed

        'ポートクローズ
        SerialPort1.Close()

    End Sub

    '------------------------------------------------------
    'データ送信処理
    '引数：送信データ
    '------------------------------------------------------
    Private Sub Data_Send(ByVal strData As String)

        Try
            '送信データ書き込み
            SerialPort1.Write(strData + ControlChars.NewLine) 'NewLine(デリミタ)を付加して送信
        Catch ex As Exception
        End Try

    End Sub

    '------------------------------------------------------
    'データ受信処理
    '戻り値：受信文字列
    '------------------------------------------------------
    Private Function Data_Receive() As String
        Dim intRcvTMOCnt As Integer = 0 '受信タイムアウトカウント

        Data_Receive = "" '戻り値初期化

        Do
            'ウェイト処理(10ms)、レスポンス受信待ち
            System.Threading.Thread.Sleep(10)
            Try
                '受信バッファ内のデータバイト数の取得
                Dim bytGetData As Byte() = New Byte(SerialPort1.BytesToRead - 1) {}
                'データバイト数のバイト配列への書き込み
                SerialPort1.Read(bytGetData, 0, bytGetData.GetLength(0))
                '受信データ結合
                Data_Receive = Data_Receive + System.Text.Encoding.GetEncoding("SHIFT-JIS").GetString(bytGetData)
            Catch ex As Exception
            End Try

            '改行コード(CR+LF)の受信確認
            If Data_Receive.Contains(ControlChars.NewLine) Then
                '改行コード(CR+LF)を受信した場合、ループ処理を抜ける
                Exit Do
            Else
                '受信タイムアウトカウント+1
                intRcvTMOCnt = intRcvTMOCnt + 1
            End If
        Loop Until 5 <= intRcvTMOCnt '50ms経過した場合、ループ処理を抜ける

    End Function

    '------------------------------------------------------
    'Button1_Clickイベント(表示更新)
    '------------------------------------------------------
    Private Sub Button1_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles Button1.Click

        Data_Send("TK6")                  '計測電圧取得コマンド送信
        srtRcvData = Data_Receive()       'データ受信
        '受信タイムアウト判定
        If TMO_Check() = False Then
            dblMeasVolt = Val(srtRcvData) '受信文字列変換(String→Double)
            Label1.Text = dblMeasVolt     '計測電圧表示
        End If

        Data_Send("TK7")                  '計測電流取得コマンド送信
        srtRcvData = Data_Receive()       'データ受信
        '受信タイムアウト判定
        If TMO_Check() = False Then
            dblMeasCurr = Val(srtRcvData) '受信文字列変換(String→Double)
            Label2.Text = dblMeasCurr     '計測電流表示
        End If

    End Sub

    '------------------------------------------------------
    'Button2_Clickイベント(設定値送信)
    '------------------------------------------------------
    Private Sub Button2_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles Button2.Click

        dblVolt = Val(TextBox1.Text)      'テキストボックス入力文字変換(String→Double)
        Data_Send("OV" & dblVolt)         '出力電圧設定コマンドの送信
        srtRcvData = Data_Receive()       'ALM128受信時は読み捨て

        dblCurr = Val(TextBox2.Text)      'テキストボックス入力文字変換(String→Double)
        Data_Send("OC" & dblCurr)         '出力電流設定コマンドの送信
        srtRcvData = Data_Receive()       'ALM128受信時は読み捨て

        dblOvp = Val(TextBox3.Text)       'テキストボックス入力文字変換(String→Double)
        Data_Send("LV" & dblOvp)          '過電圧保護設定コマンドの送信
        srtRcvData = Data_Receive()       'ALM128受信時は読み捨て

        dblOcp = Val(TextBox4.Text)       'テキストボックス入力文字変換(String→Double)
        Data_Send("LC" & dblOcp)          '過電流保護設定コマンドの送信
        srtRcvData = Data_Receive()       'ALM128受信時は読み捨て

    End Sub

    '------------------------------------------------------
    'Button3_Clickイベント(OUT ON設定)
    '------------------------------------------------------
    Private Sub Button3_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles Button3.Click

        intOutPut = 1
        Data_Send("OT1")                  '出力ON設定コマンドの送信
        srtRcvData = Data_Receive()       'ALM128受信時は読み捨て

    End Sub

    '------------------------------------------------------
    'Button4_Clickイベント(OUT OFF設定)
    '------------------------------------------------------
    Private Sub Button4_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles Button4.Click

        intOutPut = 0
        Data_Send("OT0")                  '出力OFF設定コマンドの送信
        srtRcvData = Data_Receive()       'ALM128受信時は読み捨て

    End Sub

    '------------------------------------------------------
    '受信タイムアウト判定
    '戻り値：True=タイムアウト発生
    '        False=タイムアウトなし
    '------------------------------------------------------
    Private Function TMO_Check() As Boolean

        TMO_Check = False

        If srtRcvData = "" Then
            '受信タイムアウト発生
            Me.Text = "サンプルコード(オフライン)"
            TMO_Check = True
        End If

    End Function
End Class
